@@ -57,6 +57,7 @@
 #include "watchdog/wd_internal_commands.h"
 #include "main/pool_internal_comms.h"
 
+
 #define MAX_FILE_LINE_LEN    512
 
 extern char *pcp_conf_file;		/* global variable defined in main.c holds the
@@ -1022,10 +1023,10 @@ process_reload_config(PCP_CONNECTION * frontend, char scope)
 		ereport(LOG,
 				(errmsg("PCP: sending command to watchdog to reload config cluster")));
 
-		if (wd_execute_cluster_command(WD_COMMAND_RELOAD_CONFIG_CLUSTER,0, NULL) != COMMAND_OK)
+		if (wd_execute_cluster_command(WD_COMMAND_RELOAD_CONFIG_CLUSTER, NULL) != COMMAND_OK)
 			ereport(ERROR,
 					(errmsg("PCP: error while processing reload config request for cluster"),
-					 errdetail("failed to propogate reload config command through watchdog")));
+					 errdetail("failed to propagate reload config command through watchdog")));
 	}
 
 	if(pool_signal_parent(SIGHUP) == -1)
@@ -1312,7 +1313,7 @@ process_shutown_request(PCP_CONNECTION * frontend, char mode, char tos)
 			 errdetail("shutdown mode \"%c\"", mode)));
 
 	/* quickly bail out if invalid mode is specified
-	 * because we do not want to propogate the command
+	 * because we do not want to propagate the command
 	 * with invalid mode over the watchdog network */
 	if (mode != 's' && mode != 'i' && mode != 'f' )
 	{
@@ -1324,17 +1325,21 @@ process_shutown_request(PCP_CONNECTION * frontend, char mode, char tos)
 	if (tos == 't' && pool_config->use_watchdog)
 	{
 		WDExecCommandArg wdExecCommandArg;
+		List *args_list = NULL;
 
 		strncpy(wdExecCommandArg.arg_name, "mode", sizeof(wdExecCommandArg.arg_name) - 1);
-		snprintf(wdExecCommandArg.arg_value, sizeof(wdExecCommandArg.arg_name) - 1, "%c",mode);
+		snprintf(wdExecCommandArg.arg_value, sizeof(wdExecCommandArg.arg_value) - 1, "%c",mode);
+		args_list = lappend(args_list,&wdExecCommandArg);
 
 		ereport(LOG,
 				(errmsg("PCP: sending command to watchdog to shutdown cluster")));
 
-		if (wd_execute_cluster_command(WD_COMMAND_SHUTDOWN_CLUSTER,1, &wdExecCommandArg) != COMMAND_OK)
+		if (wd_execute_cluster_command(WD_COMMAND_SHUTDOWN_CLUSTER, args_list) != COMMAND_OK)
 			ereport(ERROR,
 					(errmsg("PCP: error while processing shutdown cluster request"),
-					 errdetail("failed to propogate shutdown command through watchdog")));
+					 errdetail("failed to propagate shutdown command through watchdog")));
+
+		list_free(args_list);
 	}
 
 	pcp_write(frontend, "t", 1);
@@ -1342,7 +1347,6 @@ process_shutown_request(PCP_CONNECTION * frontend, char mode, char tos)
 	pcp_write(frontend, &len, sizeof(int));
 	pcp_write(frontend, code, sizeof(code));
 	do_pcp_flush(frontend);
-
 	terminate_pgpool(mode, true);
 }
 
